# How-to guides

1. [Customise a node](./demo/scripts/customise_a_node.py)
2. [Customise an arc](./demo/scripts/customise_an_arc.py)
3. [Customise interactions](./demo/scripts/customise_interactions.py)
